import {defineStore} from "pinia"
import {onMounted, ref} from "vue"
import {GetLoginInfo, LoginService} from "./api/user";
import {BizError} from "../core/errors.ts";
import router from "../router.ts";
import {sleep} from "../core/sleep.ts";

type LoginParam = {
    account: string;
    password: string;
}

export const LOGIN_SESSION_KEY = 'x-yy-js-data-user';

export const useUserStore = defineStore('counter', () => {
    const userInfo = ref<UserInfo>()
    const userInit = ref(false)

    // 登录
    const login = async (data: LoginParam) => {
        await sleep(1000);
        const info = await LoginService(data);
        userInfo.value = info.userinfo;
        localStorage.setItem(LOGIN_SESSION_KEY, info.token)
    }

    // 登出
    const logout = async () => {
        localStorage.removeItem(LOGIN_SESSION_KEY)
        userInfo.value = undefined;
    }
    // 更新用户信息
    const updateUserInfo = async (info: UserInfo) => {
        userInfo.value = info
    }
    // 获取用户信息
    const getUserInfo = async () => {
        const token = localStorage.getItem(LOGIN_SESSION_KEY);
        if (!token) {
            throw new BizError(401)
        }
        userInfo.value = await GetLoginInfo();
    }
    onMounted(() => {
        getUserInfo().catch((e: BizError) => {
            if (e.code == 401) {
                router.replace(`/login?redirect=${router.currentRoute.value.path}`).then(() => console.log('401 show login'))
            }
        }).finally(() => {
            console.log('onMounted inited')
            userInit.value = true
        })
    })

    return {
        userInfo,
        userInit,
        login,
        logout,
        updateUserInfo,
        getUserInfo
    }
})
